{#
  Copyright (C) 2020 CERN.

  Invenio is free software; you can redistribute it and/or modify it
  under the terms of the MIT License; see LICENSE file for more details.
#}
{% extends config.BASE_TEMPLATE %}

{%- block css %}
{{ super() }}
{{ webpack['invenio-communities-theme.css']}}
{%-endblock %}
