{# -*- coding: utf-8 -*-

  This file is part of Invenio.
  Copyright (C) 2016-2020 CERN.

  Invenio is free software; you can redistribute it and/or modify it
  under the terms of the MIT License; see LICENSE file for more details.
#}

{% extends "invenio_communities/details/base.html" %}

{%- set title = _("Search ") + community.metadata.title -%}

{%- block javascript %}
    {{ super() }}
    {{ webpack['invenio-app-rdm-search.js'] }}
{%- endblock %}

{%- block page_body %}
{{ super() }}
{% include "invenio_communities/details/search.html" %}
{%- endblock page_body %}
